@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
-static const char RCSID[]="$Id: paperkey.c 579 2009-01-28 03:28:01Z dshaw $";
+static const char RCSID[]="$Id: paperkey.c 601 2009-10-14 19:58:10Z dshaw $";
 
 #include <config.h>
 #include <stdio.h>
@@ -23,6 +23,8 @@ static const char RCSID[]="$Id: paperkey.c 579 2009-01-28 03:28:01Z dshaw $";
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #ifdef _WIN32
 #include <io.h>
 #include <fcntl.h>
@@ -74,10 +76,10 @@ static void
 usage(void)
 {
   printf("Usage: paperkey [OPTIONS]\n");
-  printf("  --help\n");
-  printf("  --version\n");
+  printf("  --help (-h)\n");
+  printf("  --version (-V)\n");
   printf("  --verbose (-v)  be more verbose\n");
-  printf("  --output        write output to this file\n");
+  printf("  --output (-o)   write output to this file\n");
   printf("  --input-type    auto, base16 or raw (binary)\n");
   printf("  --output-type   base16 or raw (binary)\n");
   printf("  --output-width  maximum width of base16 output\n");
@@ -112,7 +114,11 @@ main(int argc,char *argv[])
 
   secret_key=secrets=stdin;
 
-  while((arg=getopt_long(argc,argv,"hVv",long_options,NULL))!=-1)
+  /* Force the umask to go-rwx, as we are going to be creating files
+     that contain secret key material. */
+  umask(077);
+
+  while((arg=getopt_long(argc,argv,"hVvo:",long_options,NULL))!=-1)
     switch(arg)
       {
       case OPT_HELP:
@@ -138,6 +144,7 @@ main(int argc,char *argv[])
 	break;
 
       case OPT_OUTPUT:
+      case 'o':
 	outname=optarg;
 	break;
 
